from gestion_sport_connector import GestionSportsConnector


def make_landing_request_success(aioresponses, connector, landing_response):
    aioresponses.get(
        connector.landing_url,
        status=200,
        headers={"Set-Cookie": "PHPSESSID=987512"},
        body=landing_response,
    )


def make_login_request_fail(aioresponses, connector, login_failure_response):
    aioresponses.post(
        connector.login_url,
        status=200,
        payload=login_failure_response,
    )


def make_login_request_success(aioresponses, connector, login_success_response):
    aioresponses.post(
        connector.login_url,
        status=200,
        headers={"Set-Cookie": "COOK_COMPTE=e2be1;" "COOK_ID_CLUB=22;COOK_ID_USER=666"},
        payload=login_success_response,
    )


def set_booking_request(aioresponses, connector, booking_response):
    aioresponses.post(connector.booking_url, status=200, payload=booking_response)


def set_full_booking_requests_responses(aioresponses, connector, responses_list):
    make_landing_request_success(aioresponses, connector, responses_list[0])
    make_login_request_success(aioresponses, connector, responses_list[1])
    for response in responses_list[2:]:
        set_booking_request(aioresponses, connector, response)


def set_ongoing_bookings_response(
    aioresponses, connector, user_bookings_get_response, user_bookings_post_response
):
    set_hash_response(aioresponses, connector, user_bookings_get_response)
    set_bookings_response(aioresponses, connector, user_bookings_post_response)


def set_hash_response(aioresponses, connector, user_bookings_get_response):
    aioresponses.get(
        connector.user_bookings_url, status=200, body=user_bookings_get_response
    )


def set_bookings_response(aioresponses, connector, user_bookings_post_response):
    aioresponses.post(
        connector.user_bookings_url, status=200, payload=user_bookings_post_response
    )


def set_tournaments_sessions_response(
    aioresponses, connector: GestionSportsConnector, tournaments_sessions_response
):
    aioresponses.post(
        connector.tournaments_sessions_url,
        status=200,
        body=tournaments_sessions_response,
    )


def set_tournaments_list_response(
    aioresponses,
    connector: GestionSportsConnector,
    tournament_id,
    tournaments_list_response,
):
    url = f"{connector.tournaments_list_url}{tournament_id}"
    aioresponses.get(url, status=200, body=tournaments_list_response)


def set_full_user_bookings_responses(aioresponses, connector, responses):
    make_landing_request_success(aioresponses, connector, responses[0])
    make_login_request_success(aioresponses, connector, responses[1])
    set_ongoing_bookings_response(aioresponses, connector, *responses[2:])


def set_cancellation_response(aioresponses, connector, response):
    aioresponses.post(connector.booking_cancellation_url, status=200, payload=response)


def set_full_cancellation_by_id_responses(aioresponses, connector, responses):
    make_landing_request_success(aioresponses, connector, responses[0])
    make_login_request_success(aioresponses, connector, responses[1])
    set_hash_response(aioresponses, connector, responses[2])
    set_cancellation_response(aioresponses, connector, responses[3])


def set_full_cancellation_responses(aioresponses, connector, responses):
    make_landing_request_success(aioresponses, connector, responses[0])
    make_login_request_success(aioresponses, connector, responses[1])

    # the request to get the hash is made twice
    set_hash_response(aioresponses, connector, responses[2])
    set_hash_response(aioresponses, connector, responses[2])

    set_bookings_response(aioresponses, connector, responses[3])
    set_cancellation_response(aioresponses, connector, responses[4])


def set_full_tournaments_requests(aioresponses, connector, responses, tournament_id):
    make_landing_request_success(aioresponses, connector, responses[0])
    make_login_request_success(aioresponses, connector, responses[1])

    set_tournaments_sessions_response(aioresponses, connector, responses[2])
    set_tournaments_list_response(aioresponses, connector, tournament_id, responses[3])
